@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class EmailConfig(AppConfig):
     name = 'ax3_email'
-    verbose_name = 'AX3 Email'
+    verbose_name = 'ax3_email'
